TensorTrainRepresentation
=========================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: TensorTrainRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TensorTrainRepresentation.check_assignment
      ~TensorTrainRepresentation.check_factors
      ~TensorTrainRepresentation.create_default_assignment
      ~TensorTrainRepresentation.factor_sizes
      ~TensorTrainRepresentation.get_shapes_and_einsum_eq
      ~TensorTrainRepresentation.iter_extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: check_assignment
   .. automethod:: check_factors
   .. automethod:: create_default_assignment
   .. automethod:: factor_sizes
   .. automethod:: get_shapes_and_einsum_eq
   .. automethod:: iter_extra_repr
